@@ -110,7 +110,7 @@ void usage(char *progname)
  *
  * IN:
  * @group_id	Group identification number.
- * @opt_f	Optional flag to set.
+ * @opt_f	Optionnal flag to set.
  ***************************************************************************
  */
 void collect_group_activities(unsigned int group_id, unsigned int opt_f)
@@ -294,7 +294,7 @@ void reset_stats(void)
 	int i;
 
         for (i = 0; i < NR_ACT; i++) {
-		if ((act[i]->_nr0 > 0) && act[i]->_buf0) {
+		if ((act[i]->nr > 0) && act[i]->_buf0) {
 			memset(act[i]->_buf0, 0,
 			       (size_t) act[i]->msize * (size_t) act[i]->nr_allocated * (size_t) act[i]->nr2);
 		}
@@ -996,9 +996,11 @@ void open_ofile(int *ofd, char ofile[], int restart_mark)
 		 * we need to reallocate.
 		 */
 		act[p]->nr2 = file_act[i].nr2;
+		if (act[p]->nr_ini > act[p]->nr_allocated) {
+			act[p]->nr_allocated = act[p]->nr_ini;
+		}
 		SREALLOC(act[p]->_buf0, void,
-			 (size_t) act[p]->msize * (size_t) act[p]->nr_ini * (size_t) act[p]->nr2);
-		act[p]->nr_allocated = act[p]->nr_ini;
+			 (size_t) act[p]->msize * (size_t) act[p]->nr_allocated * (size_t) act[p]->nr2);
 
 		/* Save activity sequence */
 		id_seq[i] = file_act[i].id;
